(*
 * Copyright (C) 2003:
 *    Stefano Zacchiroli <zack@cs.unibo.it>
 *    for the HELM Team http://helm.cs.unibo.it/
 *
 *  This file is part of HELM, an Hypertextual, Electronic
 *  Library of Mathematics, developed at the Computer Science
 *  Department, University of Bologna, Italy.
 *
 *  HELM is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  HELM is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with HELM; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA  02111-1307, USA.
 *
 *  For details, see the HELM World-Wide-Web page,
 *  http://helm.cs.unibo.it/
 *)

open Http_getter_types;;

val string_of_ls_flag: http_getter_ls_flag -> string
val string_of_encoding: http_getter_encoding -> string

val is_cic_uri: string -> bool
val is_nuprl_uri: string -> bool
val is_rdf_uri: string -> bool
val is_xsl_uri: string -> bool

  (** true on blanks-only and #-commented lines, false otherwise *)
val is_blank_line: string -> bool

val http_getter_uri_of_string: string -> http_getter_uri

val patch_xml : string -> string
val patch_xsl : string -> string
val patch_dtd : string -> string

val return_html_error: string -> out_channel -> unit
val return_html_internal_error: string -> out_channel -> unit
  (** return an HTML HTTP response from the given string, embedding it in an
  "H1" element of an HTML page; content-type is set to text/html *)
val return_html_msg: string -> out_channel -> unit
  (** return an HTTP response using given string as content; content-type is set
  to text/html *)
val return_html_raw: string -> out_channel -> unit
  (** return an HTTP response using given string as content; content-type is set
  to text/xml *)
val return_xml_raw: string -> out_channel -> unit
 (** return a bad request http response *)
val return_400: string -> out_channel -> unit
  (**
  @param fname name of the file to be sent
  @param contype Content-Type header value
  @param contenc Content-Enconding header value
  @param patch_fun function used to patch file contents
  @param gunzip is meaningful only if a patch function is provided. If gunzip
  is true patch_fun is applied to the uncompressed version of the file. The file
  is then compressed again and send to client
  @param outchan output channel over which sent file fname *)
val return_file:
  fname:string ->
  ?contype:string -> ?contenc:string ->
  ?patch_fun:(string -> string) -> ?gunzip:bool ->
  out_channel ->
    unit

