(*
 * Copyright (C) 2003:
 *    Stefano Zacchiroli <zack@cs.unibo.it>
 *    for the HELM Team http://helm.cs.unibo.it/
 *
 *  This file is part of HELM, an Hypertextual, Electronic
 *  Library of Mathematics, developed at the Computer Science
 *  Department, University of Bologna, Italy.
 *
 *  HELM is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  HELM is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with HELM; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 *  MA  02111-1307, USA.
 *
 *  For details, see the HELM World-Wide-Web page,
 *  http://helm.cs.unibo.it/
 *)

open Http_getter_types;;

  (* general information *)

val version       : string        (* getter version *)

  (* environment gathered data *)

val cic_dbm       : string        (* XML map DBM file for CIC *)
val nuprl_dbm     : string        (* XML map DBM file for NuPRL *)
val rdf_dbm       : string        (* RDF map DBM file *)
val xsl_dbm       : string        (* XSL map DBM file *)
val xml_index     : string        (* XMLs' index *)
val rdf_index     : string        (* RDFs' index *)
val xsl_index     : string        (* XSLTs' index *)
val cic_dir       : string        (* XMLs' directory  for CIC*)
val nuprl_dir     : string        (* XMLs' directory for NuPRL*)
val rdf_dir       : string        (* RDFs' directory *)
val dtd_dir       : string        (* DTDs' root directory *)
val servers_file  : string        (* servers.txt file *)
val port          : int           (* port on which getter listens *)
val dtd_base_url  : string        (* base URL for DTD downloading *)

  (* derived data *)

val host          : string          (* host on which getter listens *)
val my_own_url    : string          (* URL at which contact getter *)
val servers       : string list ref (* servers list *)
val cache_mode    : http_getter_encoding  (* cached files encoding *)
val conf_file     : string          (* configuration file's full path *)
val conf_dir      : string          (* directory where conf_file resides *)

  (* misc *)

val reload: unit -> unit            (* reload servers list *)
val env_to_string : unit -> string  (* dump a textual representation of the
                                    current http_getter settings on an output
                                    channel*)

